(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     81216,       2226]
NotebookOptionsPosition[     73784,       1983]
NotebookOutlinePosition[     75555,       2034]
CellTagsIndexPosition[     75476,       2029]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Hermite Interpolation with Mathematica ", "Section",
 CellChangeTimes->{{3.549012361192299*^9, 3.549012365650884*^9}, {
  3.549012451662456*^9, 3.549012466432775*^9}}],

Cell["Robert Vajda, University of Szeged, Hungary", "Text",
 CellChangeTimes->{{3.549012374308373*^9, 3.549012390741525*^9}, {
  3.549303312206479*^9, 3.549303313728737*^9}}],

Cell["\<\
Joint work with Laszlo Stacho

CADGME 2012- Novi Sad
June 22, 2012\
\>", "Text",
 CellChangeTimes->{{3.54901240216692*^9, 3.549012418879597*^9}, {
  3.549012832417967*^9, 3.549012839053696*^9}, {3.549303282340524*^9, 
  3.549303305110997*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Problem", "Section",
 CellChangeTimes->{{3.549012848725568*^9, 3.549012853161702*^9}}],

Cell["Given three finite lists, X, F, DF.", "Text",
 CellChangeTimes->{{3.54901286161161*^9, 3.549012891204399*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "=", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["x", "1"], ",", 
      SubscriptBox["x", "2"], ",", "...", ",", 
      SubscriptBox["x", "n"]}], "}"}]}], TraditionalForm]]],
 " wlog ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["x", "1"], "<", 
       SubscriptBox["x", "2"], "<"}], "..."}], "<", 
     SubscriptBox["x", "n"]}], ")"}], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"F", "=", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["f", "1"], ",", 
      SubscriptBox["f", "2"], ",", "...", ",", 
      SubscriptBox["f", "n"]}], "}"}]}], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"DF", "=", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["df", "1"], ",", 
      SubscriptBox["df", "2"], ",", "...", ",", 
      SubscriptBox["df", "n"]}], "}"}]}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["x", "j"], ",", 
     SubscriptBox["f", "j"], ",", " ", 
     RowBox[{
      SubscriptBox["df", "j"], "\[Element]"}]}]}], TraditionalForm]]],
 "\[DoubleStruckCapitalR])."
}], "Text",
 CellChangeTimes->{{3.549012898953265*^9, 3.549013278452754*^9}, {
   3.549013328061604*^9, 3.549013408255588*^9}, 3.54930455728063*^9}],

Cell[TextData[{
 "Find a poly H such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[ForAll]", 
      RowBox[{"1", "\[LessEqual]", "j", "\[LessEqual]", "n"}]], 
     RowBox[{"H", "[", 
      SubscriptBox["x", "j"], "]"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", "j"], " ", "\[And]", " ", 
      RowBox[{
       RowBox[{"H", "'"}], " ", "[", 
       SubscriptBox["x", "j"], "]"}]}], "=", 
     SubscriptBox["df", "j"]}]}], TraditionalForm]]],
 ",\n"
}], "Text",
 CellChangeTimes->{{3.549013291511007*^9, 3.549013363457175*^9}, {
  3.54901341265728*^9, 3.549013527115346*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Theorem", "Section",
 CellChangeTimes->{{3.549013535057167*^9, 3.549013539526382*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Exists]", 
    RowBox[{"!", " ", "H"}]}], TraditionalForm]]],
 "of degree at most ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"2", "n"}], "-", "1"}], TraditionalForm]]],
 " which satisfies all the interpolation constraints. "
}], "Text",
 CellChangeTimes->{{3.549013545182017*^9, 3.549013584682745*^9}, {
  3.549301796562901*^9, 3.549301869007341*^9}}],

Cell[TextData[{
 "\nQuestion: What is the Newtonian Form of ",
 Cell[BoxData[
  FormBox["H", TraditionalForm]],
  FormatType->"TraditionalForm"],
 "?"
}], "Text",
 CellChangeTimes->{{3.549013596538898*^9, 3.549013632143359*^9}, {
  3.549013670946268*^9, 3.549013674195308*^9}, {3.549301878335394*^9, 
  3.549301881925127*^9}, {3.549304587468794*^9, 3.549304588736041*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.549013639447012*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Example", "Section",
 CellChangeTimes->{{3.549014763203195*^9, 3.549014766218853*^9}}],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"X", "=", 
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}]}], ",", " ", 
   RowBox[{"F", "=", 
    RowBox[{"{", 
     RowBox[{"2", ",", "0"}], "}"}]}], ",", " ", 
   RowBox[{"DF", "=", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}]}], TraditionalForm]]]], "Text",
 CellChangeTimes->{{3.549014899420257*^9, 3.549014928578867*^9}, {
   3.549014963162776*^9, 3.549014970389626*^9}, 3.549015204426255*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pe", "[", "x_", "]"}], "=", 
   RowBox[{"2", "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "1"}], ")"}], "2"]}], "+", 
    RowBox[{
     FractionBox["3", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "3"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "1"}], ")"}], "2"]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.549014978722935*^9, 3.549015025395879*^9}, {
  3.549303851307915*^9, 3.549303867500068*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"pe", "[", "x", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.549015184303572*^9, 3.549015188767598*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["3", "4"]}], "+", 
  FractionBox[
   RowBox[{"25", " ", "x"}], "4"], "-", 
  FractionBox[
   RowBox[{"17", " ", 
    SuperscriptBox["x", "2"]}], "4"], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox["x", "3"]}], "4"]}]], "Output",
 CellChangeTimes->{3.549015190444344*^9, 3.549302196800798*^9, 
  3.549303869460214*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"pe", "[", "1", "]"}], ",", 
      RowBox[{"pe", "[", "3", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"pe", "[", "x", "]"}], ",", "x"}], "]"}], "/.", 
       RowBox[{"x", "\[Rule]", "1"}]}], ",", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"pe", "[", "x", "]"}], ",", "x"}], "]"}], "/.", 
       RowBox[{"x", "\[Rule]", "3"}]}]}], "}"}]}], "}"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.549015055085886*^9, 3.549015144002771*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"2", "0"},
    {"0", "1"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.549015131650135*^9, 3.549015144619652*^9}, 
   3.549302198179133*^9, 3.549303870828086*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Example", "Section",
 CellChangeTimes->{{3.549302207909945*^9, 3.549302212593432*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"pe", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "4"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "3.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", ".02", "]"}], ",", "Red", ",", 
      RowBox[{"Thickness", "[", ".01", "]"}], ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{".5", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1.5", ",", "2"}], "}"}]}], "}"}], "]"}], ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2.646", ",", 
           RowBox[{"-", ".353"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3.353", ",", ".353"}], "}"}]}], "}"}], "]"}], ",", "Black",
       ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<Slope=0\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2.2"}], "}"}]}], "]"}], ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<Slope=1\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"2.8", ",", ".2"}], "}"}]}], "]"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], ",", 
   RowBox[{"Ticks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "2"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.549302224898261*^9, 3.54930225132946*^9}, {
   3.54930232480858*^9, 3.549302690593281*^9}, 3.549302724985951*^9, {
   3.549302770582914*^9, 3.549302791112335*^9}, {3.549302925934347*^9, 
   3.549302956257255*^9}, {3.549303005220462*^9, 3.549303006235558*^9}, {
   3.54930306276362*^9, 3.549303235427901*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdl3c8le//x61zjGQlUYomlVAUWu8rCdkZUUlEUkpIND8aSFYqiZCZ7JF9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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["y", TraditionalForm]},
  AxesOrigin->{0, 0},
  Epilog->{
    PointSize[0.02], 
    RGBColor[1, 0, 0], 
    Thickness[0.01], 
    LineBox[{{0.5, 2}, {1.5, 2}}], 
    LineBox[{{2.646, -0.353}, {3.353, 0.353}}], 
    GrayLevel[0], 
    PointBox[{{1, 2}, {3, 0}}], 
    InsetBox[
     FormBox["\"Slope=0\"", TraditionalForm], {1, 2.2}], 
    InsetBox[
     FormBox["\"Slope=1\"", TraditionalForm], {2.8, 0.2}]},
  PlotRange->{{0, 3.5}, {-1, 2.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic},
  Ticks->{{{1, 
      FormBox["1", TraditionalForm]}, {3, 
      FormBox["3", TraditionalForm]}}, {{0, 
      FormBox["0", TraditionalForm]}, {2, 
      FormBox["2", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{
  3.549302356310379*^9, {3.549302431219104*^9, 3.549302454969038*^9}, 
   3.549302564495714*^9, {3.549302609873627*^9, 3.549302618775559*^9}, 
   3.549302669865401*^9, 3.549302792541706*^9, 3.549303008513683*^9, 
   3.54930307392268*^9, 3.549303111941528*^9, 3.549303172669997*^9, {
   3.549303212741967*^9, 3.54930323654519*^9}}]
}, {2}]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Remark (Uniqueness)", "Section",
 CellChangeTimes->{{3.549303680093728*^9, 3.549303709808783*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pe2", "[", "x_", "]"}], "=", 
   RowBox[{"2", "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "1"}], ")"}], "2"]}], "+", 
    RowBox[{
     FractionBox["3", "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "1"}], ")"}], "2"], 
     RowBox[{"(", 
      RowBox[{"x", "-", "3"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "1"}], ")"}], "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "3"}], ")"}], "2"]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.549303736352994*^9, 3.549303811121021*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"pe2", "[", "1", "]"}], ",", 
      RowBox[{"pe2", "[", "3", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"pe2", "[", "x", "]"}], ",", "x"}], "]"}], "/.", 
       RowBox[{"x", "\[Rule]", "1"}]}], ",", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"pe2", "[", "x", "]"}], ",", "x"}], "]"}], "/.", 
       RowBox[{"x", "\[Rule]", "3"}]}]}], "}"}]}], "}"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.549015055085886*^9, 3.549015144002771*^9}, {
  3.549303832623076*^9, 3.549303837494039*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"2", "0"},
    {"0", "1"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.549303838067856*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Algorithm Poly-Seed", "Section",
 CellChangeTimes->{{3.549015239769801*^9, 3.549015248812704*^9}}],

Cell["\<\
Idea: Construct the poly H step by step considering only one extra \
interpolation constraint per round\
\>", "Text",
 CellChangeTimes->{{3.549015259195695*^9, 3.54901526896866*^9}, 
   3.549015602041269*^9, {3.549015646577364*^9, 3.549015662124173*^9}, {
   3.549015696534294*^9, 3.549015768067181*^9}, {3.549301905759356*^9, 
   3.549301910779599*^9}, 3.549304720403451*^9}],

Cell[TextData[{
 "Observation:  We can put the interpolation constraints in several different \
order, the only restriction is: at any point never use the constraint on the \
derivative ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["df", "j"], ")"}], TraditionalForm]]],
 "before the constraint on the function value ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"(", 
     SubscriptBox["f", "j"], ")"}]}], TraditionalForm]]],
 "  "
}], "Text",
 CellChangeTimes->{{3.549015722263044*^9, 3.549015727845421*^9}, {
  3.549015792204025*^9, 3.549015820966975*^9}, {3.549015869703377*^9, 
  3.549015944672042*^9}, {3.549016412455785*^9, 3.549016416298505*^9}, {
  3.549301916519211*^9, 3.549301928463747*^9}, {3.549301960387752*^9, 
  3.54930214052853*^9}, {3.557639023407973*^9, 3.557639029065686*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.549015722779811*^9, 3.549015725601974*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.549015732290074*^9, 3.549015733827428*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Example", "Section",
 CellChangeTimes->{{3.549303558265338*^9, 3.549303564242938*^9}}],

Cell["\<\

Init. poly of degree 0\
\>", "Text",
 CellChangeTimes->{{3.54930402668309*^9, 3.549304046851232*^9}, {
  3.549304745095871*^9, 3.549304755587422*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p0", "=", 
  RowBox[{
  "F", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]], "Input",
 CellChangeTimes->{{3.549303926490876*^9, 3.549303958961615*^9}, 
   3.549304141502369*^9}],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{3.549304142282584*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"p0", "+", 
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{"x", "-", "1"}], ")"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.549303961426202*^9, 3.549303985961137*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{"p1", ",", "x"}], "]"}], "/.", 
     RowBox[{"x", "\[Rule]", 
      RowBox[{"X", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}],
     ")"}], "\[Equal]", 
   RowBox[{"DF", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.549303991293063*^9, 3.549304019404044*^9}, {
  3.549304054182416*^9, 3.549304115473776*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"A", "\[Rule]", "0"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.549304116657539*^9, 3.549304145220177*^9}}]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"p1", "=", 
    RowBox[{"p0", "+", 
     RowBox[{"0", 
      RowBox[{"(", 
       RowBox[{"x", "-", "x1"}], ")"}]}]}]}], TraditionalForm]]],
 ",\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"p2", "=", 
    RowBox[{"p1", "+", 
     RowBox[{"A", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "x1"}], ")"}], "2"]}]}]}], TraditionalForm]]],
 " etc., \n\nApriori Form, Sucessive Solving of Linear Equations to Get \
Coeffs A.\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"p0", ",", " ", "p1", ",", " ", "p2", ",", "...", ",", 
    RowBox[{
     SubscriptBox["p", 
      RowBox[{
       RowBox[{"2", "n"}], "-", "1"}]], "=", "H"}]}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.54930414916339*^9, 3.549304427733107*^9}, 
   3.549307170074677*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Intapp: Newtonian Forms of 
the Hermite Polynomial\
\>", "Section",
 CellChangeTimes->{{3.549303456414355*^9, 3.549303505163583*^9}, {
  3.54930479243594*^9, 3.549304797713705*^9}, {3.549307184584419*^9, 
  3.549307184979285*^9}, {3.55763944594162*^9, 3.55763945949248*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Panel", "[", 
          RowBox[{"Grid", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Prepend", "[", 
              RowBox[{"DF", ",", "\"\<DF:\>\""}], "]"}], ",", 
             RowBox[{"Prepend", "[", 
              RowBox[{"F", ",", "\"\<F:\>\""}], "]"}]}], "}"}], "]"}], "]"}], 
         ",", 
         RowBox[{"GraphPlot", "[", 
          RowBox[{
           RowBox[{"MM", "[", "n", "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "-", ".2"}], ",", 
                RowBox[{
                 RowBox[{"Length", "[", "X", "]"}], "+", ".2"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", ".3"}], ",", "1.3"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"VertexCoordinateRules", "\[Rule]", 
            RowBox[{"Join", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"j", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", "0"}], "}"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"j", ",", 
                  RowBox[{"Length", "[", "X", "]"}]}], "}"}]}], "]"}], ",", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Length", "[", "X", "]"}], "+", "j"}], "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", "1"}], "}"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"j", ",", 
                  RowBox[{"Length", "[", "X", "]"}]}], "}"}]}], "]"}]}], 
             "]"}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"200", ",", "100"}], "}"}]}], ",", 
           RowBox[{"VertexRenderingFunction", "\[Rule]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"GM", "[", "#2", "]"}], ",", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"ChFLists", "[", 
                   RowBox[{"IntegerPart", "[", "#2", "]"}], "]"}], ",", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"#2", "\[Equal]", "GInd"}], ",", 
                    RowBox[{"Circle", "[", 
                    RowBox[{"#1", ",", ".15"}], "]"}], ",", 
                    RowBox[{"Circle", "[", 
                    RowBox[{"#1", ",", ".1"}], "]"}]}], "]"}], ",", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"#2", "\[Equal]", "GInd"}], ",", 
                    RowBox[{"Disk", "[", 
                    RowBox[{"#1", ",", ".15"}], "]"}], ",", 
                    RowBox[{"Disk", "[", 
                    RowBox[{"#1", ",", ".1"}], "]"}]}], "]"}]}], "]"}]}], 
               "}"}], "&"}], ")"}]}]}], "]"}], ",", 
         RowBox[{"Panel", "[", 
          RowBox[{"Grid", "[", 
           RowBox[{"{", 
            RowBox[{"MapIndexed", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Button", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"n", "=", "\[IndentingNewLine]", 
                  RowBox[{"f", "[", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"#2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "n"}], "]"}]}]}], 
                "]"}], "&"}], ",", "ll"}], "]"}], "}"}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"TableForm", "[", 
          RowBox[{"{", "X", "}"}], "]"}], ",", "GHP"}], "}"}]}], "}"}], ",", 
     RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "1"}], "}"}], ",", "1", ",", "100", ",", ".1", ",", 
     RowBox[{"Enabled", "\[Rule]", "False"}]}], "}"}], ",", 
   RowBox[{"ControlPlacement", "\[Rule]", "Right"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{"\"\<Hermite Interpolation 2012\>\"", ",", "Red"}], "]"}]}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.548314888102923*^9, 3.548314929691449*^9}, {
   3.548314981858608*^9, 3.548314987225355*^9}, {3.548315311500796*^9, 
   3.548315342884755*^9}, {3.548315712647141*^9, 3.548315713123194*^9}, {
   3.548315801485484*^9, 3.548315804617364*^9}, {3.548316179916695*^9, 
   3.548316186054715*^9}, {3.54831622915113*^9, 3.548316378243766*^9}, {
   3.548316410540696*^9, 3.548316499219422*^9}, {3.548316530026795*^9, 
   3.548316595013738*^9}, {3.548316728750044*^9, 3.548316734819201*^9}, {
   3.548316779357605*^9, 3.548316921022937*^9}, {3.548317000821188*^9, 
   3.548317006777083*^9}, {3.548317142684719*^9, 3.54831719697901*^9}, {
   3.548322257218038*^9, 3.548322292987436*^9}, {3.548322564674753*^9, 
   3.548322572162453*^9}, {3.548322734800705*^9, 3.548322811566593*^9}, {
   3.548322881657816*^9, 3.548322901650501*^9}, {3.548322990608241*^9, 
   3.548323006178976*^9}, {3.548323098604316*^9, 3.54832310380341*^9}, {
   3.548323159273073*^9, 3.548323163452338*^9}, {3.548323346304578*^9, 
   3.548323356085968*^9}, {3.548324000220865*^9, 3.548324010544343*^9}, {
   3.548324097758394*^9, 3.548324098229264*^9}, {3.548423774211701*^9, 
   3.548423816424759*^9}, {3.548423949267869*^9, 3.548424062898084*^9}, {
   3.548424385466024*^9, 3.548424440564555*^9}, {3.548424470814726*^9, 
   3.548424489172836*^9}, {3.548424877203453*^9, 3.548424925098955*^9}, {
   3.54842496603623*^9, 3.548425075492552*^9}, {3.548427214056854*^9, 
   3.548427372086461*^9}, {3.548444749769598*^9, 3.548444797716641*^9}, {
   3.548444853837641*^9, 3.548444874446938*^9}, {3.548445018629651*^9, 
   3.548445137816854*^9}, {3.548445220795445*^9, 3.548445231365694*^9}, {
   3.548445267033145*^9, 3.548445379953303*^9}, {3.548445470483631*^9, 
   3.548445470982984*^9}, {3.548446141974026*^9, 3.5484461703265*^9}, 
   3.548446210081356*^9, {3.548500988276954*^9, 3.54850099503974*^9}, {
   3.548501282887985*^9, 3.548501353636868*^9}, {3.548501679329696*^9, 
   3.548501731623321*^9}, {3.548501792561098*^9, 3.548501797017749*^9}, {
   3.548501847050131*^9, 3.548501876102778*^9}, {3.548501949582119*^9, 
   3.548501966876831*^9}, {3.548501999119051*^9, 3.548502005443234*^9}, {
   3.548502062908378*^9, 3.548502083203508*^9}, {3.548502135580039*^9, 
   3.548502149472498*^9}, {3.548502186326708*^9, 3.548502190244674*^9}, {
   3.548502227279869*^9, 3.548502454215302*^9}, {3.54850248573968*^9, 
   3.548502573676778*^9}, {3.548502707622806*^9, 3.548502754367378*^9}, {
   3.54850379314111*^9, 3.548503835514182*^9}, {3.549024869563183*^9, 
   3.549024882246881*^9}, {3.549026040557837*^9, 3.549026060040992*^9}, {
   3.54902651825606*^9, 3.54902654259704*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`n$$ = {{19, 16}, {20, 17}}, Typeset`show$$ =
     True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`n$$], 1}, 1, 100, 0.1}}, Typeset`size$$ = {
    546., {113., 124.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`n$821$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`n$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`n$$, $CellContext`n$821$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Grid[{{
          Panel[
           Grid[{
             Prepend[$CellContext`DF, "DF:"], 
             Prepend[$CellContext`F, "F:"]}]], 
          GraphPlot[
           $CellContext`MM[$CellContext`n$$], 
           PlotRange -> {{1 - 0.2, Length[$CellContext`X] + 0.2}, {-0.3, 
             1.3}}, VertexCoordinateRules -> Join[
             Table[$CellContext`j -> {$CellContext`j, 0}, {$CellContext`j, 
               Length[$CellContext`X]}], 
             Table[
             Length[$CellContext`X] + $CellContext`j -> {$CellContext`j, 
                1}, {$CellContext`j, 
               Length[$CellContext`X]}]], ImageSize -> {200, 100}, 
           VertexRenderingFunction -> ({
             $CellContext`GM[#2], 
             If[
              $CellContext`ChFLists[
               IntegerPart[#2]], 
              If[#2 == $CellContext`GInd, 
               Circle[#, 0.15], 
               Circle[#, 0.1]], 
              If[#2 == $CellContext`GInd, 
               Disk[#, 0.15], 
               Disk[#, 0.1]]]}& )], 
          Panel[
           Grid[{
             MapIndexed[Button[#, $CellContext`n$$ = $CellContext`f[
                 
                 Part[#2, 
                  1], $CellContext`n$$]]& , $CellContext`ll]}]]}, \
{$CellContext`x, 
          TableForm[{$CellContext`X}], $CellContext`GHP}}, Frame -> All], 
      "Specifications" :> {{{$CellContext`n$$, 1}, 1, 100, 0.1, Enabled -> 
         False}}, 
      "Options" :> {
       ControlPlacement -> Right, FrameLabel -> 
        Style["Hermite Interpolation 2012", 
          RGBColor[1, 0, 0]]}, "DefaultOptions" :> {}],
     ImageSizeCache->{833., {186., 197.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`DF = {0, 1}, $CellContext`F = {2, 
        0}, $CellContext`MM[
         Pattern[$CellContext`n, 
          Blank[]]] := $CellContext`M, $CellContext`M = {{1, 0, 0, 0}, {0, 1, 
        0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}, $CellContext`X = {1, 
        3}, $CellContext`GM[
         Pattern[$CellContext`j, 
          Blank[]]] := 
       If[$CellContext`j > Length[$CellContext`X], Red, 
         Blue], $CellContext`ChFLists[
         Pattern[$CellContext`j, 
          Blank[]]] := If[$CellContext`j > Length[$CellContext`X], 
         If[
          MemberQ[
           Part[$CellContext`MDF, All, 1], $CellContext`j], True, False], 
         If[
          MemberQ[
           Part[$CellContext`MF, All, 1], $CellContext`j], True, 
          False]], $CellContext`MDF = {{3, 0}, {4, 1}}, $CellContext`MF = {{1,
         2}, {2, 0}}, $CellContext`GInd = 1, $CellContext`f[6, 
         Pattern[$CellContext`s, 
          Blank[]]] := ($CellContext`X = {1, 3}; $CellContext`F = {2, 
          0}; $CellContext`DF = {0, 1}; $CellContext`GInd = 
         1; $CellContext`PGInd = -1; $CellContext`GHP = 0; $CellContext`M = 
         IdentityMatrix[2 Length[$CellContext`X]]; $CellContext`MF = 
         Transpose[{
            Range[
             
             Length[$CellContext`X]], $CellContext`F}]; $CellContext`CMF = {}; \
$CellContext`MDF = Transpose[{Range[
              Length[$CellContext`X]] + 
            Length[$CellContext`X], $CellContext`DF}]), $CellContext`f[
         Pattern[$CellContext`i, 
          Blank[]], 
         Pattern[$CellContext`s, 
          Blank[]]] := Module[{}, If[$CellContext`i == 5, 
           If[
           1 <= $CellContext`GInd <= 
            Length[$CellContext`X], $CellContext`GHP = $CellContext`GHP + \
$CellContext`A Product[
                 
                 If[$CellContext`j == $CellContext`GInd, 
                  1, ($CellContext`x - Part[$CellContext`X, $CellContext`j])^(
                   2 - Count[
                    Part[$CellContext`MF, All, 1], $CellContext`j] - Count[
                    Part[$CellContext`MDF, All, 1], $CellContext`j + 
                    Length[$CellContext`X]])], {$CellContext`j, 
                  Length[$CellContext`X]}]; $CellContext`GHP = 
             ReplaceAll[$CellContext`GHP, 
               Part[
                Solve[
                ReplaceAll[$CellContext`GHP, $CellContext`x -> 
                   Part[$CellContext`X, $CellContext`GInd]] == 
                 Part[$CellContext`F, $CellContext`GInd], $CellContext`A], 
                1]]; $CellContext`MF = 
             DeleteCases[$CellContext`MF, {$CellContext`GInd, 
                PatternTest[
                 Blank[], NumberQ]}]; 
            If[$CellContext`PGInd > 0, 
              Part[$CellContext`M, $CellContext`PGInd, $CellContext`GInd] = 
              1]; $CellContext`PGInd = $CellContext`GInd, 
            If[
             And[
             Length[$CellContext`X] + 1 <= $CellContext`GInd <= 
              2 Length[$CellContext`X], 
              Cases[$CellContext`MF, {$CellContext`GInd - 
                 Length[$CellContext`X], 
                 
                 Blank[]}] == {}], $CellContext`GHP = $CellContext`GHP + \
$CellContext`A Product[
                  
                  If[$CellContext`j == $CellContext`GInd - 
                    Length[$CellContext`X], $CellContext`x - 
                   Part[$CellContext`X, $CellContext`j], ($CellContext`x - 
                    Part[$CellContext`X, $CellContext`j])^(2 - Count[
                    Part[$CellContext`MF, All, 1], $CellContext`j] - Count[
                    Part[$CellContext`MDF, All, 1], $CellContext`j + 
                    Length[$CellContext`X]])], {$CellContext`j, 
                   Length[$CellContext`X]}]; $CellContext`GHP = 
              ReplaceAll[$CellContext`GHP, 
                Part[
                 Solve[ReplaceAll[
                    D[$CellContext`GHP, $CellContext`x], $CellContext`x -> 
                    Part[$CellContext`X, $CellContext`GInd - 
                    Length[$CellContext`X]]] == 
                  Part[$CellContext`DF, $CellContext`GInd - 
                    Length[$CellContext`X]], $CellContext`A], 
                 1]]; $CellContext`MDF = 
              DeleteCases[$CellContext`MDF, {$CellContext`GInd, 
                 PatternTest[
                  Blank[], NumberQ]}]; 
             If[$CellContext`PGInd > 0, 
               Part[$CellContext`M, $CellContext`PGInd, $CellContext`GInd] = 
               1]; $CellContext`PGInd = $CellContext`GInd]], 
           If[
            And[$CellContext`i == 4, 
             Or[
              Inequality[1, LessEqual, $CellContext`GInd, Less, 
               Length[$CellContext`X]], 
              Length[$CellContext`X] < $CellContext`GInd < 
              2 Length[$CellContext`X]]], 
            Increment[$CellContext`GInd], 
            If[
             And[$CellContext`i == 3, 
              Or[
               Inequality[1, Less, $CellContext`GInd, LessEqual, 
                Length[$CellContext`X]], 
               Inequality[
               Length[$CellContext`X] + 1, Less, $CellContext`GInd, LessEqual,
                 2 Length[$CellContext`X]]]], 
             Decrement[$CellContext`GInd], 
             If[
              
              And[$CellContext`i == 1, 1 <= $CellContext`GInd <= 
               Length[$CellContext`X]], $CellContext`GInd = $CellContext`GInd + 
               Length[$CellContext`X], 
              If[
               And[$CellContext`i == 2, 
                Inequality[
                 Length[$CellContext`X], Less, $CellContext`GInd, LessEqual, 
                 2 Length[$CellContext`X]]], $CellContext`GInd = \
$CellContext`GInd - Length[$CellContext`X]]]]]]; $CellContext`s + 
          1], $CellContext`PGInd = -1, $CellContext`GHP = 
       0, $CellContext`CMF = {}, $CellContext`ll = {
        "\[DoubleUpArrow]", "\[DoubleDownArrow]", "\[DoubleLeftArrow]", 
         "\[DoubleRightArrow]", "+", "I"}}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.548502455062507*^9, {3.548502488595892*^9, 3.548502524183459*^9}, 
   3.548502574319874*^9, {3.548502723867499*^9, 3.548502755581206*^9}, 
   3.548502945050994*^9, 3.548502991821344*^9, 3.548503639780693*^9, 
   3.548503717065256*^9, 3.54850380285017*^9, 3.548503836689461*^9, 
   3.548526878380546*^9, 3.549024100259972*^9, 3.549025000779861*^9, 
   3.549025338981438*^9, 3.549026064333745*^9, 3.54902654403237*^9}]
}, {2}]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Coeffs (2,0,-1/2,3/4)", "Section",
 CellChangeTimes->{{3.549305260373034*^9, 3.549305288909189*^9}}],

Cell["\<\

Classical order, generalized Newton Scheme\
\>", "Text",
 CellChangeTimes->{{3.549305296837981*^9, 3.54930534598219*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"Style", "[", 
       RowBox[{"2", ",", "Red"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", 
      RowBox[{"Style", "[", 
       RowBox[{"0", ",", "Red", ",", "Underlined"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "0", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], ",", "Red"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "0", ",", 
      RowBox[{"Style", "[", 
       RowBox[{"1", ",", "Underlined"}], "]"}], ",", "1", ",", 
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{"3", "/", "4"}], ",", "Red"}], "]"}]}], "}"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.549306494772639*^9, 3.54930657331346*^9}, {
  3.549306608274303*^9, 3.549306717883947*^9}, {3.549306750120357*^9, 
  3.549306818688698*^9}, {3.549306946455151*^9, 3.549306989226476*^9}}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"1", 
     StyleBox["2",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"1", "2", 
     StyleBox["0",
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontVariations->{"Underline"->True},
      FontColor->RGBColor[1, 0, 0]], "\<\"\"\>", "\<\"\"\>"},
    {"3", "0", 
     RowBox[{"-", "1"}], 
     StyleBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]], "\<\"\"\>"},
    {"3", "0", 
     StyleBox["1",
      StripOnInput->False,
      FontVariations->{"Underline"->True}], "1", 
     StyleBox[
      FractionBox["3", "4"],
      StripOnInput->False,
      LineColor->RGBColor[1, 0, 0],
      FrontFaceColor->RGBColor[1, 0, 0],
      BackFaceColor->RGBColor[1, 0, 0],
      GraphicsColor->RGBColor[1, 0, 0],
      FontColor->RGBColor[1, 0, 0]]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{1, 
     Style[2, 
      RGBColor[1, 0, 0]]}, {1, 2, 
     Style[0, 
      RGBColor[1, 0, 0], Underlined]}, {3, 0, -1, 
     Style[
      Rational[-1, 2], 
      RGBColor[1, 0, 0]]}, {3, 0, 
     Style[1, Underlined], 1, 
     Style[
      Rational[3, 4], 
      RGBColor[1, 0, 0]]}}]]], "Output",
 CellChangeTimes->{{3.549306963391783*^9, 3.549306989992716*^9}}]
}, {2}]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[TextData[{
 "Coeffs (2,0,-1/2,",
 StyleBox["3/4",
  FontColor->RGBColor[1, 0, 0]],
 ") and Series Expansion [Closed Form]"
}], "Section",
 CellChangeTimes->{{3.548526940054637*^9, 3.548526952025433*^9}, {
  3.548529072928711*^9, 3.54852909399557*^9}, {3.548529145562875*^9, 
  3.548529159320878*^9}, {3.549306039189724*^9, 3.549306046181954*^9}, {
  3.549306321528648*^9, 3.549306325198589*^9}, {3.549306372732388*^9, 
  3.549306374681708*^9}, {3.549307459504604*^9, 3.549307475451906*^9}, {
  3.549307792522196*^9, 3.549307800106841*^9}}],

Cell["\<\
H=\[Sum]j A[j] \[Omega][j], where A[j]=\[Sum]k y[k] \[CapitalGamma]n,k \
\>", "Text",
 CellChangeTimes->{{3.548529635287696*^9, 3.548529752509677*^9}, 
   3.549307570403469*^9}],

Cell["\<\
How do we get e.g. the lc=3/4? Compute the \[CapitalGamma]\[CloseCurlyQuote]s \
as coeffs of series expansions:\
\>", "Text",
 CellChangeTimes->{{3.548528224552638*^9, 3.548528231327895*^9}, {
  3.548529105957448*^9, 3.548529128155359*^9}, {3.548529767137952*^9, 
  3.548529796341271*^9}, {3.549305681243236*^9, 3.549305681710489*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"scf3", "=", "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{
      RowBox[{"1", "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{
          "X", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], "2"]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"X", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ",", "1"}], "}"}]}], "]"}], ",", 
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{
      RowBox[{"1", "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{
          "X", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], "2"]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"X", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ",", "0"}], "}"}]}], "]"}], ",", 
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{
      RowBox[{"1", "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{
          "X", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
         ")"}], "2"]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"X", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        ",", "1"}], "}"}]}], "]"}], ",", 
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{
      RowBox[{"1", "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{
          "X", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
         ")"}], "2"]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"X", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        ",", "0"}], "}"}]}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.548528452641132*^9, 3.548528460788241*^9}, {
  3.548528492311895*^9, 3.548528519302587*^9}, {3.548529000272618*^9, 
  3.548529008552475*^9}, {3.549305754571903*^9, 3.549305808936173*^9}, {
  3.549307724406895*^9, 3.549307743002656*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "4"], ",", 
   FractionBox["1", "4"], ",", 
   RowBox[{"-", 
    FractionBox["1", "4"]}], ",", 
   FractionBox["1", "4"]}], "}"}]], "Output",
 CellChangeTimes->{3.54852852022277*^9, 3.548529017470389*^9, 
  3.549305816213695*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "3", "]"}], "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"F", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
     RowBox[{"DF", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"F", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
     RowBox[{"DF", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
    "}"}], ".", "scf3"}]}]], "Input",
 CellChangeTimes->{{3.54852865241585*^9, 3.548528770113871*^9}, {
  3.548529034830195*^9, 3.548529038846793*^9}, {3.54852982499182*^9, 
  3.548529829272544*^9}, {3.549305835492005*^9, 3.5493058458424*^9}}],

Cell[BoxData[
 FractionBox["3", "4"]], "Output",
 CellChangeTimes->{3.54930738871153*^9}]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.549307394561273*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[TextData[{
 "Coeffs (2,0,",
 StyleBox["-1/2",
  FontColor->RGBColor[1, 0, 0]],
 ",3/4) and Series Expansion [Closed Form]"
}], "Section",
 CellChangeTimes->{{3.548526940054637*^9, 3.548526952025433*^9}, {
  3.548529072928711*^9, 3.54852909399557*^9}, {3.548529145562875*^9, 
  3.548529159320878*^9}, {3.549306055424018*^9, 3.549306057081047*^9}, {
  3.54930626302414*^9, 3.549306283273155*^9}, {3.549306380136954*^9, 
  3.549306381976625*^9}, {3.549307495696801*^9, 3.54930751593852*^9}, {
  3.549307804951231*^9, 3.549307811708761*^9}}],

Cell["\<\
H=\[Sum]j A[j] \[Omega][j], where A[j]=\[Sum]k y[k] \[CapitalGamma]n,k \
\>", "Text",
 CellChangeTimes->{{3.548529635287696*^9, 3.548529752509677*^9}, 
   3.549307576369483*^9}],

Cell["\<\
How do we get e.g. the 2nd c=-1/2? Compute the \[CapitalGamma]\
\[CloseCurlyQuote]s as coeffs of series expansions:\
\>", "Text",
 CellChangeTimes->{{3.548528224552638*^9, 3.548528231327895*^9}, {
  3.548529105957448*^9, 3.548529128155359*^9}, {3.548529767137952*^9, 
  3.548529796341271*^9}, {3.549305681243236*^9, 3.549305681710489*^9}, {
  3.549306072819485*^9, 3.549306085537533*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"scf2", "=", "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{
      RowBox[{"1", "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{
          "X", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], "1"]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"X", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ",", "1"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{
      RowBox[{"1", "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{
          "X", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
         ")"}], "1"]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"X", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ",", "0"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{
      RowBox[{"1", "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", 
          RowBox[{
          "X", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
         ")"}], "2"]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"X", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        ",", "0"}], "}"}]}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.548528452641132*^9, 3.548528460788241*^9}, {
  3.548528492311895*^9, 3.548528519302587*^9}, {3.548529000272618*^9, 
  3.548529008552475*^9}, {3.549305754571903*^9, 3.549305808936173*^9}, {
  3.549306089708589*^9, 3.549306090291755*^9}, {3.549306135914634*^9, 
  3.549306147608045*^9}, {3.54930618726239*^9, 3.549306213547276*^9}, {
  3.549307759958233*^9, 3.549307771829672*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "4"]}], ",", 
   RowBox[{"-", 
    FractionBox["1", "2"]}], ",", 
   FractionBox["1", "4"]}], "}"}]], "Output",
 CellChangeTimes->{3.54852852022277*^9, 3.548529017470389*^9, 
  3.549305816213695*^9, 3.549306222982499*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", "2", "]"}], "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"F", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
     RowBox[{"DF", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"F", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
    "}"}], ".", "scf2"}]}]], "Input",
 CellChangeTimes->{{3.54852865241585*^9, 3.548528770113871*^9}, {
  3.548529034830195*^9, 3.548529038846793*^9}, {3.54852982499182*^9, 
  3.548529829272544*^9}, {3.549305835492005*^9, 3.5493058458424*^9}, {
  3.549306153749774*^9, 3.549306161929958*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", "2"]}]], "Output",
 CellChangeTimes->{
  3.548528728031531*^9, 3.548528771097489*^9, 3.548529040914189*^9, {
   3.548529830013387*^9, 3.548529858656822*^9}, 3.549305847800363*^9, 
   3.549306224786297*^9}]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.549307381407733*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Outlook", "Section",
 CellChangeTimes->{{3.549305432919622*^9, 3.54930543588592*^9}}],

Cell["\<\
\[Dash] more general problem setting: constraints on higher order derivatives
\[Dash] interpolation over finite fields (poly\[LeftRightArrow]poly function) \

\[Dash] numerical issues, computational complexity
\[Dash] applicatons: Triangular decompositions of Hermite-Vandermonde matrices\
\>", "Text",
 CellChangeTimes->{{3.549305437285607*^9, 3.549305564645546*^9}, {
   3.54930589168512*^9, 3.5493059486033*^9}, 3.549307314790711*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Literature", "Section",
 CellChangeTimes->{{3.557639159356449*^9, 3.557639165910655*^9}}],

Cell["\<\
This talk is based on the paper 

L. L. Stacho \[LongDash] R. Vajda: 
Hermite interpolation sequences over finite fields (2012, preprint, submitted)\
\>", "Text",
 CellChangeTimes->{{3.549305437285607*^9, 3.549305564645546*^9}, {
   3.54930589168512*^9, 3.5493059486033*^9}, 3.549307314790711*^9, {
   3.557639187972511*^9, 3.557639337418812*^9}, 3.557639378696367*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Aux", "Section",
 CellChangeTimes->{{3.549303360406381*^9, 3.549303365284528*^9}}],

Cell[CellGroupData[{

Cell["\<\

Hermite aux\
\>", "Section",
 CellChangeTimes->{{3.54829788105479*^9, 3.548297892558741*^9}, {
  3.548444511011151*^9, 3.548444512219057*^9}, {3.548503322701504*^9, 
  3.54850334836947*^9}, {3.548503674626135*^9, 3.548503680790821*^9}, {
  3.549303415406586*^9, 3.549303416508982*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.54850335443282*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GM", "[", "j_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"j", ">", 
     RowBox[{"Length", "[", "X", "]"}]}], ",", "Red", ",", "Blue"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.548300571000982*^9, 3.548300649894148*^9}, {
  3.548300697515287*^9, 3.548300799580934*^9}, {3.548301001772312*^9, 
  3.548301034932595*^9}, {3.548301081209772*^9, 3.548301109633853*^9}, {
  3.548301171949191*^9, 3.548301178593982*^9}, {3.548425310744409*^9, 
  3.548425338554675*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ChFLists", "[", "j_", "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"j", ">", 
     RowBox[{"Length", "[", "X", "]"}]}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"MemberQ", "[", 
       RowBox[{
        RowBox[{"MDF", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", "j"}], "]"}], ",", 
      "True", ",", "False"}], "]"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"MemberQ", "[", 
       RowBox[{
        RowBox[{"MF", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", "j"}], "]"}], ",", 
      "True", ",", "False"}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.548301329265623*^9, 3.548301415437963*^9}, {
  3.548301445622571*^9, 3.548301553050002*^9}, {3.548301856740839*^9, 
  3.54830192472461*^9}, {3.548498977376491*^9, 3.548498978338509*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ll", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<\[DoubleUpArrow]\>\"", ",", "\"\<\[DoubleDownArrow]\>\"", ",", 
     "\"\<\[DoubleLeftArrow]\>\"", ",", "\"\<\[DoubleRightArrow]\>\"", ",", 
     "\"\<+\>\"", ",", "\"\<I\>\""}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.548311599097618*^9, 3.54831164419978*^9}, {
  3.548311683503544*^9, 3.548311697861358*^9}, {3.548315502944541*^9, 
  3.548315504722454*^9}, {3.548315537027479*^9, 3.548315544540913*^9}, {
  3.549025249308397*^9, 3.549025252952468*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"6", ",", "s_"}], "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"X", "=", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3"}], "}"}]}], ";", 
     RowBox[{"F", "=", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}]}], ";", 
     RowBox[{"DF", "=", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}], ";", 
     RowBox[{"GInd", "=", "1"}], ";", 
     RowBox[{"PGInd", "=", 
      RowBox[{"-", "1"}]}], ";", 
     RowBox[{"GHP", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"M", "=", 
      RowBox[{"IdentityMatrix", "[", 
       RowBox[{"2", 
        RowBox[{"Length", "[", "X", "]"}]}], "]"}]}], ";", "\n", 
     RowBox[{"MF", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"Length", "[", "X", "]"}], "]"}], ",", "F"}], "}"}], 
       "]"}]}], ";", 
     RowBox[{"CMF", "=", 
      RowBox[{"{", "}"}]}], ";", "\n", 
     RowBox[{"MDF", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"Length", "[", "X", "]"}], "]"}], "+", 
          RowBox[{"Length", "[", "X", "]"}]}], ",", "DF"}], "}"}], "]"}]}]}], 
    ")"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.549025260228949*^9, 3.549025267788448*^9}, {
   3.549025314841427*^9, 3.549025328604149*^9}, 3.549025396326943*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"i_", ",", "s_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"i", "\[Equal]", "\[IndentingNewLine]", "5"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"1", "<=", "GInd", "\[LessEqual]", 
          RowBox[{"Length", "[", "X", "]"}]}], ",", 
         RowBox[{
          RowBox[{"GHP", "=", 
           RowBox[{"GHP", "+", 
            RowBox[{"A", " ", 
             RowBox[{"Product", "[", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"j", "\[Equal]", "GInd"}], ",", "1", ",", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"x", "-", 
                    RowBox[{"X", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], ")"}], "^", 
                  RowBox[{"(", 
                   RowBox[{"2", "-", 
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"MF", "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", "j"}], 
                    "]"}], "-", 
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"MDF", "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"j", "+", 
                    RowBox[{"Length", "[", "X", "]"}]}]}], "]"}]}], ")"}]}]}],
                 "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", 
                 RowBox[{"Length", "[", "X", "]"}]}], "}"}]}], "]"}]}]}]}], 
          ";", 
          RowBox[{"GHP", "=", 
           RowBox[{"GHP", "/.", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Solve", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"GHP", "/.", 
                   RowBox[{"x", "\[Rule]", 
                    RowBox[{"X", "[", 
                    RowBox[{"[", "GInd", "]"}], "]"}]}]}], ")"}], "\[Equal]", 
                 
                 RowBox[{"F", "[", 
                  RowBox[{"[", "GInd", "]"}], "]"}]}], ",", "A"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], ")"}]}]}], ";", 
          RowBox[{"MF", "=", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{"MF", ",", 
             RowBox[{"{", 
              RowBox[{"GInd", ",", 
               RowBox[{"_", "?", "NumberQ"}]}], "}"}]}], "]"}]}], ";", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"PGInd", ">", "0"}], ",", 
            RowBox[{
             RowBox[{"M", "[", 
              RowBox[{"[", 
               RowBox[{"PGInd", ",", "GInd"}], "]"}], "]"}], "=", "1"}]}], 
           "]"}], ";", 
          RowBox[{"PGInd", "=", "GInd"}]}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Length", "[", "X", "]"}], "+", "1"}], "<=", "GInd", 
             "\[LessEqual]", 
             RowBox[{"2", 
              RowBox[{"Length", "[", "X", "]"}]}]}], "\[And]", 
            RowBox[{
             RowBox[{"Cases", "[", 
              RowBox[{"MF", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"GInd", "-", 
                  RowBox[{"Length", "[", "X", "]"}]}], ",", "_"}], "}"}]}], 
              "]"}], "\[Equal]", 
             RowBox[{"{", "}"}]}]}], ",", 
           RowBox[{
            RowBox[{"GHP", "=", 
             RowBox[{"GHP", "+", 
              RowBox[{"A", " ", 
               RowBox[{"Product", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"j", "\[Equal]", 
                    RowBox[{"GInd", "-", 
                    RowBox[{"Length", "[", "X", "]"}]}]}], ",", 
                   RowBox[{"x", "-", 
                    RowBox[{"X", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], ",", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"x", "-", 
                    RowBox[{"X", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], ")"}], "^", 
                    RowBox[{"(", 
                    RowBox[{"2", "-", 
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"MF", "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", "j"}], 
                    "]"}], "-", 
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"MDF", "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"j", "+", 
                    RowBox[{"Length", "[", "X", "]"}]}]}], "]"}]}], ")"}]}]}],
                   "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", 
                   RowBox[{"Length", "[", "X", "]"}]}], "}"}]}], "]"}]}]}]}], 
            ";", 
            RowBox[{"GHP", "=", 
             RowBox[{"GHP", "/.", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Solve", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"D", "[", 
                    RowBox[{"GHP", ",", "x"}], "]"}], "/.", 
                    RowBox[{"x", "\[Rule]", 
                    RowBox[{"X", "[", 
                    RowBox[{"[", 
                    RowBox[{"GInd", "-", 
                    RowBox[{"Length", "[", "X", "]"}]}], "]"}], "]"}]}]}], 
                    ")"}], "\[Equal]", 
                   RowBox[{"DF", "[", 
                    RowBox[{"[", 
                    RowBox[{"GInd", "-", 
                    RowBox[{"Length", "[", "X", "]"}]}], "]"}], "]"}]}], ",", 
                  "A"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ")"}]}]}], ";", 
            RowBox[{"MDF", "=", 
             RowBox[{"DeleteCases", "[", 
              RowBox[{"MDF", ",", 
               RowBox[{"{", 
                RowBox[{"GInd", ",", 
                 RowBox[{"_", "?", "NumberQ"}]}], "}"}]}], "]"}]}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"PGInd", ">", "0"}], ",", 
              RowBox[{
               RowBox[{"M", "[", 
                RowBox[{"[", 
                 RowBox[{"PGInd", ",", "GInd"}], "]"}], "]"}], "=", "1"}]}], 
             "]"}], ";", 
            RowBox[{"PGInd", "=", "GInd"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"i", "\[Equal]", "4"}], "\[And]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"1", "<=", "GInd", "<", 
             RowBox[{"Length", "[", "X", "]"}]}], "\[Or]", 
            RowBox[{
             RowBox[{"Length", "[", "X", "]"}], "<", "GInd", "<", 
             RowBox[{"2", 
              RowBox[{"Length", "[", "X", "]"}]}]}]}], ")"}]}], ",", 
         RowBox[{"GInd", "++"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"i", "\[Equal]", "3"}], "\[And]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"1", "<", "GInd", "\[LessEqual]", 
               RowBox[{"Length", "[", "X", "]"}]}], "\[Or]", 
              RowBox[{
               RowBox[{
                RowBox[{"Length", "[", "X", "]"}], "+", "1"}], "<", "GInd", "<=", 
               RowBox[{"2", 
                RowBox[{"Length", "[", "X", "]"}]}]}]}], ")"}]}], ",", 
           RowBox[{"GInd", "--"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"i", "\[Equal]", "1"}], "\[And]", 
              RowBox[{"1", "\[LessEqual]", "GInd", "\[LessEqual]", 
               RowBox[{"Length", "[", "X", "]"}]}]}], ",", 
             RowBox[{"GInd", "=", 
              RowBox[{"GInd", "+", 
               RowBox[{"Length", "[", "X", "]"}]}]}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"i", "\[Equal]", "2"}], "\[And]", 
                RowBox[{
                 RowBox[{"Length", "[", "X", "]"}], "<", "GInd", 
                 "\[LessEqual]", 
                 RowBox[{"2", 
                  RowBox[{"Length", "[", "X", "]"}]}]}]}], ",", 
               RowBox[{"GInd", "=", 
                RowBox[{"GInd", "-", 
                 RowBox[{"Length", "[", "X", "]"}]}]}]}], "]"}]}], "]"}]}], 
          "]"}]}], "]"}]}], "]"}], ";", 
     RowBox[{"s", "+", "1"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.548312437726415*^9, 3.548312466678331*^9}, {
   3.548312540050215*^9, 3.548312642453967*^9}, {3.548312757513631*^9, 
   3.548312787712821*^9}, {3.548312857436327*^9, 3.548312858912975*^9}, {
   3.548312926999693*^9, 3.548312973693679*^9}, {3.548313596236192*^9, 
   3.548313599019124*^9}, {3.548315566677245*^9, 3.548315617130812*^9}, {
   3.548315650445326*^9, 3.54831567961007*^9}, {3.548315902436682*^9, 
   3.548315948876327*^9}, {3.548323964699606*^9, 3.548323981376364*^9}, {
   3.54832404558785*^9, 3.548324045914945*^9}, 3.548424139606896*^9, {
   3.548424341024898*^9, 3.548424370125274*^9}, 3.548424630277819*^9, {
   3.548425435200757*^9, 3.548425438207455*^9}, {3.548425497480765*^9, 
   3.548425580348347*^9}, {3.548425652427325*^9, 3.548425655793477*^9}, {
   3.548425737877848*^9, 3.548425795830121*^9}, {3.548425844962837*^9, 
   3.548425881269173*^9}, {3.548425929665482*^9, 3.548425931673206*^9}, {
   3.548426007619837*^9, 3.548426012891953*^9}, {3.548426118625435*^9, 
   3.548426123877353*^9}, {3.548426209577444*^9, 3.548426215102015*^9}, {
   3.548426253399268*^9, 3.548426268316568*^9}, {3.548426325967111*^9, 
   3.548426379749157*^9}, {3.548426416802907*^9, 3.548426509012822*^9}, {
   3.548426542833874*^9, 3.54842654649604*^9}, {3.548426675026004*^9, 
   3.548426698640329*^9}, {3.548426738160854*^9, 3.548426808761878*^9}, {
   3.548426962692055*^9, 3.548427038322356*^9}, {3.54842752946821*^9, 
   3.548427531908861*^9}, {3.548446234200832*^9, 3.548446275437154*^9}, {
   3.548446410759195*^9, 3.548446420939977*^9}, {3.548447021110457*^9, 
   3.548447180317986*^9}, {3.54844721225008*^9, 3.548447218542474*^9}, {
   3.548447287252604*^9, 3.548447392418599*^9}, {3.548447615842481*^9, 
   3.548447616878995*^9}, {3.548447658497797*^9, 3.54844769153109*^9}, {
   3.548447885854627*^9, 3.548447888897468*^9}, {3.548447984405596*^9, 
   3.548447992803619*^9}, {3.548448197368302*^9, 3.548448199637271*^9}, {
   3.548448311168725*^9, 3.548448312619396*^9}, {3.548500149647113*^9, 
   3.548500175265462*^9}, {3.548500346343836*^9, 3.548500364485506*^9}, {
   3.548500649132887*^9, 3.548500753924509*^9}, {3.54902341743234*^9, 
   3.549023502919088*^9}, {3.549023538163853*^9, 3.549023597588517*^9}, {
   3.549023642743909*^9, 3.54902365372539*^9}, {3.549024016133843*^9, 
   3.549024087839063*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MM", "[", "n_", "]"}], ":=", "M"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.548315317424871*^9, 3.548315337673609*^9}}]
}, Closed]]
}, Open  ]]
},
ScreenStyleEnvironment->"SlideShow",
WindowSize->{767, 544},
WindowMargins->{{1, Automatic}, {5, Automatic}},
ShowSelection->True,
FrontEndVersion->"8.0 for Linux x86 (32-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[579, 22, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1323, 49, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[3665, 137, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[4780, 178, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[7997, 294, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[20758, 560, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[23047, 644, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[24697, 693, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[27172, 788, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[44239, 1160, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[47882, 1279, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[52442, 1416, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[56944, 1547, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[57623, 1569, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[58238, 1591, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 74134, 1995}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[668, 27, 173, 2, 74, "Section"],
Cell[844, 31, 174, 2, 30, "Text"],
Cell[1021, 35, 253, 8, 87, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1323, 49, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1412, 54, 92, 1, 74, "Section"],
Cell[1507, 57, 116, 1, 30, "Text"],
Cell[1626, 60, 1352, 49, 68, "Text"],
Cell[2981, 111, 635, 20, 122, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3665, 137, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[3754, 142, 92, 1, 126, "Section"],
Cell[3849, 145, 417, 13, 83, "Text"],
Cell[4269, 160, 372, 9, 83, "Text"],
Cell[4644, 171, 87, 1, 90, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4780, 178, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[4869, 183, 92, 1, 126, "Section"],
Cell[4964, 186, 477, 13, 49, "Text"],
Cell[5444, 201, 572, 18, 87, "Input"],
Cell[CellGroupData[{
Cell[6041, 223, 154, 3, 52, "Input"],
Cell[6198, 228, 388, 13, 75, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6623, 246, 662, 21, 127, "Input"],
Cell[7288, 269, 648, 18, 75, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7997, 294, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[8086, 299, 92, 1, 126, "Section"],
Cell[CellGroupData[{
Cell[8203, 304, 2318, 65, 145, "Input"],
Cell[10524, 371, 10176, 182, 373, "Output"]
}, {2}]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20758, 560, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[20847, 565, 104, 1, 126, "Section"],
Cell[20954, 568, 713, 24, 127, "Input"],
Cell[CellGroupData[{
Cell[21692, 596, 715, 22, 127, "Input"],
Cell[22410, 620, 576, 17, 75, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23047, 644, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[23136, 649, 104, 1, 126, "Section"],
Cell[23243, 652, 386, 7, 83, "Text"],
Cell[23632, 661, 826, 20, 193, "Text"],
Cell[24461, 683, 92, 1, 52, "Input"],
Cell[24556, 686, 92, 1, 52, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24697, 693, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[24786, 698, 92, 1, 126, "Section"],
Cell[24881, 701, 161, 5, 83, "Text"],
Cell[CellGroupData[{
Cell[25067, 710, 212, 5, 52, "Input"],
Cell[25282, 717, 70, 1, 52, "Output"]
}, Open  ]],
Cell[25367, 721, 232, 7, 52, "Input"],
Cell[CellGroupData[{
Cell[25624, 732, 492, 13, 52, "Input"],
Cell[26119, 747, 169, 4, 52, "Output"]
}, Open  ]],
Cell[26303, 754, 820, 28, 248, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27172, 788, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[27261, 793, 284, 6, 189, "Section"],
Cell[CellGroupData[{
Cell[27570, 803, 7144, 148, 240, "Input"],
Cell[34717, 953, 9464, 200, 408, "Output"]
}, {2}]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[44239, 1160, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[44328, 1165, 106, 1, 126, "Section"],
Cell[44437, 1168, 132, 4, 83, "Text"],
Cell[CellGroupData[{
Cell[44594, 1176, 1066, 29, 69, "Input"],
Cell[45663, 1207, 2161, 65, 159, "Output"]
}, {2}]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47882, 1279, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[47971, 1284, 544, 11, 189, "Section"],
Cell[48518, 1297, 187, 4, 49, "Text"],
Cell[48708, 1303, 345, 6, 83, "Text"],
Cell[CellGroupData[{
Cell[49078, 1313, 2121, 59, 392, "Input"],
Cell[51202, 1374, 289, 9, 71, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51528, 1388, 671, 14, 52, "Input"],
Cell[52202, 1404, 89, 2, 71, "Output"]
}, Open  ]],
Cell[52306, 1409, 87, 1, 90, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[52442, 1416, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[52531, 1421, 542, 11, 189, "Section"],
Cell[53076, 1434, 187, 4, 49, "Text"],
Cell[53266, 1440, 398, 7, 83, "Text"],
Cell[CellGroupData[{
Cell[53689, 1451, 1870, 48, 307, "Input"],
Cell[55562, 1501, 299, 9, 71, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55898, 1515, 639, 14, 52, "Input"],
Cell[56540, 1531, 253, 6, 71, "Output"]
}, Open  ]],
Cell[56808, 1540, 87, 1, 90, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[56944, 1547, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[57033, 1552, 91, 1, 126, "Section"],
Cell[57127, 1555, 447, 8, 253, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[57623, 1569, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[57712, 1574, 95, 1, 126, "Section"],
Cell[57810, 1577, 379, 8, 185, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[58238, 1591, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[58305, 1594, 88, 1, 74, "Section"],
Cell[CellGroupData[{
Cell[58418, 1599, 296, 7, 73, "Section"],
Cell[58717, 1608, 113, 2, 50, "Input",
 InitializationCell->True],
Cell[58833, 1612, 548, 13, 30, "Input",
 InitializationCell->True],
Cell[59384, 1627, 937, 26, 50, "Input",
 InitializationCell->True],
Cell[60324, 1655, 574, 12, 30, "Input",
 InitializationCell->True],
Cell[60901, 1669, 1484, 44, 88, "Input",
 InitializationCell->True],
Cell[62388, 1715, 11192, 258, 354, "Input",
 InitializationCell->True],
Cell[73583, 1975, 173, 4, 30, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
